## 指数周线行情

接口：index_weekly

描述：获取指数周线行情

限量：单次最大1000行记录，可分批获取，总量不限制

积分：用户需要至少600积分才可以调取，积分越多频次越高，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 |
| trade_date | str | N | 交易日期 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS指数代码 |
| trade_date | str | Y | 交易日 |
| close | float | Y | 收盘点位 |
| open | float | Y | 开盘点位 |
| high | float | Y | 最高点位 |
| low | float | Y | 最低点位 |
| pre_close | float | Y | 昨日收盘点 |
| change | float | Y | 涨跌点位 |
| pct_chg | float | Y | 涨跌幅 |
| vol | float | Y | 成交量（手） |
| amount | float | Y | 成交额（千元） |

接口用法

```python
pro = ts.pro_api()

df = pro.index_weekly(ts_code='000001.SH', start_date='20180101', end_date='20190329', fields='ts_code,trade_date,open,high,low,close,vol,amount')
```

或者

```python
df = pro.index_weekly(trade_date='20190329', fields='ts_code,trade_date,open,high,low,close,vol,amount')
```

数据样例

```python
ts_code  trade_date     close       open       high        low  \
0   000001.SH   20190329  3090.7580  3058.8016  3093.0329  2987.7717   
```